@@ -5,7 +5,7 @@ echo "Running huge-merge.pl --keep test-A1 "
 
 huge-merge.pl --keep test-A1
 
-sort ./test-A1/merge.2 > ./test-A1/t0
+sort ./test-A1/merge.* > ./test-A1/t0
 sort ./test-A1/test-A1.reqd > ./test-A1/t1
 
 diff ./test-A1/t0 ./test-A1/t1 > ./test-A1/var
@@ -18,4 +18,4 @@ else
 	cat ./test-A1/var;
 endif
 
-/bin/rm -f ./test-A1/t0 ./test-A1/t1 ./test-A1/var ./test-A1/merge.2
+/bin/rm -f ./test-A1/t0 ./test-A1/t1 ./test-A1/var ./test-A1/merge.*
